pub enum FileCompressionType {
Stored,
Deflated,
StoredTampered,
DeflatedTampered,
}Expand description
Represents the type of compression used for a file in a ZIP archive.
Variants
Stored
The file is stored without compression.
Deflated
The file is compressed using the Deflate algorithm.
StoredTampered
The file appears tampered but is actually stored without compression.
DeflatedTampered
The file appears tampered but is actually compressed with Deflate.