Signature

Enum Signature 

pub enum Signature {
    V1(Vec<CertificateInfo>),
    V2(Vec<CertificateInfo>),
    V3(Vec<CertificateInfo>),
    V31(Vec<CertificateInfo>),
    V4,
    ApkChannelBlock(String),
    StampBlockV1(CertificateInfo),
    StampBlockV2(CertificateInfo),
    PackerNextGenV2(Vec<u8>),
    GooglePlayFrosting,
    VasDollyV2(String),
    Unknown,
}
Describe used signature scheme in APK

Basic overview: https://source.android.com/docs/security/features/apksigning

Variants



V1(Vec<CertificateInfo>)



V2(Vec<CertificateInfo>)



V3(Vec<CertificateInfo>)



V31(Vec<CertificateInfo>)



V4

APK signature scheme v4

See: https://source.android.com/docs/security/features/apksigning/v4

Right now it’s just a stub. Need help/a hint on how to correctly implement the parsing of this signature.



ApkChannelBlock(String)

Some usefull information from apk channel block



StampBlockV1(CertificateInfo)



StampBlockV2(CertificateInfo)



PackerNextGenV2(Vec<u8>)



GooglePlayFrosting

Google Play Frosting Metadata

We just highlight the presence of the block, because the full structure is unknown to anyone in public space

For more details you can inspect: https://github.com/avast/apkverifier/blob/master/signingblock/frosting.go#L23



VasDollyV2(String)

Some apk protector/parser, idk, seen in the wild

The channel information in the ID-Value pair

See: https://edgeone.ai/document/58005



Unknown

Got something that we don’t know yet

Implementations

Source

impl Signature

pub fn name(&self) -> String