pub struct AXML {
pub root: Element,
}Expand description
Represents an Android Binary XML (AXML) file.
This struct holds the root element of the parsed XML structure.
You can use this struct to traverse the XML tree, extract attributes, or get a string representation of the XML.
Fields
root: ElementImplementations
Sourceimpl AXML
impl AXML
Sourcepub fn get_xml_string(&self) -> String
pub fn get_xml_string(&self) -> String
Sourcepub fn get_attribute_value(
&self,
tag: &str,
name: &str,
arsc: Option<&ARSC>,
) -> Option<String>
pub fn get_attribute_value( &self, tag: &str, name: &str, arsc: Option<&ARSC>, ) -> Option<String>
Retrieves the value of an attribute from a specific tag.
Sourcepub fn get_root_attribute_values<'a>(
&'a self,
tag: &'a str,
name: &'a str,
) -> impl Iterator<Item = &'a str> + 'a
pub fn get_root_attribute_values<'a>( &'a self, tag: &'a str, name: &'a str, ) -> impl Iterator<Item = &'a str> + 'a
Returns an iterator over attribute values for direct children with a specific tag.
This is a faster version of AXML::get_all_attribute_values that only iterates over the root’s direct children
Sourcepub fn get_all_attribute_values<'a>(
&'a self,
tag: &'a str,
name: &'a str,
) -> impl Iterator<Item = &'a str> + 'a
pub fn get_all_attribute_values<'a>( &'a self, tag: &'a str, name: &'a str, ) -> impl Iterator<Item = &'a str> + 'a
Returns an iterator over attribute values for all descendants with a specific tag.
Sourcepub fn get_main_activities(&self) -> impl Iterator<Item = &str>
pub fn get_main_activities(&self) -> impl Iterator<Item = &str>
Extracts the main launcher activities from an APK manifest.
Algorithm:
- Search for all
<activity>and<activity-alias>tags. - Look for
android.intent.action.MAINwithandroid.intent.category.LAUNCHERorandroid.intent.category.INFO.